@@ -4,7 +4,7 @@ use strict;
 
 use Class::DBI::Loader::Relationship;
 
-use MasonX::Maypole 0.216;
+use MasonX::Maypole;
 use base 'MasonX::Maypole';
 
 BeerDB->setup( 'dbi:mysql:BeerDB', 
@@ -13,13 +13,14 @@ BeerDB->setup( 'dbi:mysql:BeerDB',
                );
 
 BeerDB->config->{view}           = 'MasonX::Maypole::View';
-BeerDB->config->{template_root}  = '/usr/home/dave/www/beerdb/htdocs/beerdb';
-BeerDB->config->{uri_base}       = '/beerdb';
+BeerDB->config->{template_root}  = '/home/beerdb/www/www/htdocs';
+BeerDB->config->{uri_base}       = '/';
 BeerDB->config->{rows_per_page}  = 10;
 BeerDB->config->{display_tables} = [ qw( beer brewery pub style ) ];
+BeerDB->config->{application_name} = 'The Beer Database';
 
 BeerDB->config->masonx->{comp_root}  = [ [ factory => '/usr/local/www/maypole/factory' ] ];
-BeerDB->config->masonx->{data_dir}   = '/usr/home/dave/www/beerdb/mdata/maypole';
+BeerDB->config->masonx->{data_dir}   = '/home/beerdb/www/www/mdata/maypole';
 BeerDB->config->masonx->{in_package} = 'BeerDB::TestApp';
 
 BeerDB::Brewery->untaint_columns( printable => [qw/name notes url/] );
